require 'stringio'
require 'timeout'
require "./run.rb"

special_things = %w'@ $ ! > , [ ] ~ : ; f F m M i I e E nil if del stdin superpad version type show  1,2,3 0,0 1,2,,3,4 "asdf" "" 1000'

all = ["\n",*' '..'~'] + special_things*3 + [" "]*2

$ReadStdinLines = lines(Promise.new{ str_to_lazy_list("ab12") }).const

# todo idea: take all tests and make larger programs that are almost correct
# todo check that value matches type

n = 100000

1.upto(8){|program_size|
  ([all.size**program_size*2+100,n].min).times{|i|
    program = program_size.times.map{ all.sample }*""
    $stdout = StringIO.new("")
    begin
      STDERR.puts program
      Timeout::timeout(0.01) {
        run_and_do_io(program, false, false)
      }
    rescue IogiiError,Timeout::Error => e
#       STDERR.puts e.message
    rescue => e
      STDERR.puts "failed, program was:"
      STDERR.puts program
      raise e
    end
  }
}
